==> pingoo-1.0.1.tgz: package/lib/index.js <==
'use strict';
const path = require('path')

const default_options = {
    port: 7337,
    route: 'ping',
}

const packageFile = require(path.dirname(require.main.filename) + '/package.json')

const response = {
    name: packageFile.name,
    version: packageFile.version,
    status: 'OK',
    statusCode: '200',
    time: new Date().toISOString(),
    process: {
        uptime: process.uptime(),
        title: process.title,
        version: process.versions.node,
        pid: process.pid
    }
}

function requestHandler(req, res, params) {
    if (req.url === '/' + params['route']) {
        res.writeHead(200, { 'Content-Type': 'application/json' })
        res.write(JSON.stringify(response), 'utf8')
    } else {
        res.writeHead(404, { 'Content-Type': 'text/plain' })
        res.write('Error 404! Page not found.')
    }
    res.end()
}

const createPing = function (options) {
    let params = {}

    if (options) {
        if (typeof options['port'] === 'number' && options['port'] >= 1024 && options['port'] <= 65535) params['port'] = options['port']
        else params['port'] = default_options['port']

        if (typeof options['route'] === 'string') params['route'] = options['route']
        else params['port'] = default_options['route']
    } else params = default_options

    let server = require('http').createServer((req, res) => requestHandler(req, res, params))
    server.listen(params['port'], (err) => {
        if (err) return console.error('Something bad happened on server listening on port' + params['port'] + ' :', err)
        console.log('Pingoo is available on port ' + params['port'] + ' on route /' + params['route'])
    })

    return server
}

module.exports = createPing

==> pingoo-1.1.0.tgz: package/lib/index.js <==
'use strict';
const path = require('path')
const default_options = {
    port: 7337,
    route: 'ping',
    debug: false
}

var packageFile = {}
try {
    packageFile = require(path.dirname(require.main.filename) + '/package.json')
} catch (err) {
    packageFile = {
        name: 'unknown',
        version: 'unknown'
    }
}
const response = {
    name: packageFile.name,
    version: packageFile.version,
    status: 'OK',
    statusCode: '200',
    time: new Date().toISOString(),
    process: {
        uptime: process.uptime(),
        title: process.title,
        version: process.versions.node,
        pid: process.pid
    }
}

function requestHandler(req, res, params) {
    if (req.url === '/' + params['route']) {
        res.writeHead(200, { 'Content-Type': 'application/json' })
        res.write(JSON.stringify(response), 'utf8')
    } else {
        res.writeHead(404, { 'Content-Type': 'text/plain' })
        res.write('Error 404! Page not found.')
    }
    res.end()
}

const createPing = function (options) {
    let params = {}

    if (options) {
        if (typeof options['port'] === 'number' && options['port'] >= 1024 && options['port'] <= 65535) params['port'] = options['port']
        else params['port'] = default_options['port']

        if (typeof options['route'] === 'string') params['route'] = options['route']
        else params['port'] = default_options['route']

        if (typeof options['debug'] === 'boolean') params['debug'] = options['debug']
        else params['debug'] = default_options['debug']
    } else params = default_options

    let server = require('http').createServer((req, res) => requestHandler(req, res, params))
    server.listen(params['port'], (err) => {
        if (err) return console.error('Something bad happened on server listening on port' + params['port'] + ' :', err)
        if (params['debug']) console.log('Pingoo is available on port ' + params['port'] + ' on route /' + params['route'])
    })

    return server
}

module.exports = createPing
